MISSION_ACTION constant
String
const MISSION_ACTION
When you need to know when the user clicks on a mission card.
Implementation
static const String MISSION_ACTION = 'MISSION_ACTION';
When you need to know when the user clicks on a mission card.
static const String MISSION_ACTION = 'MISSION_ACTION';