TRIVIA_CLOSED constant
String
const TRIVIA_CLOSED
When you need to know when the user closed the Trivia game on our platform.
Implementation
static const String TRIVIA_CLOSED = 'TRIVIA_CLOSED';
When you need to know when the user closed the Trivia game on our platform.
static const String TRIVIA_CLOSED = 'TRIVIA_CLOSED';