Flourish class
Properties
- category ↔ String
-
getter/setter pair
- customerCode ↔ String
-
getter/setter pair
- endpoint ↔ Endpoint
-
getter/setter pair
- environment ↔ Environment
-
getter/setter pair
- eventManager ↔ EventManager
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTokenValid → bool
-
no setter
- language ↔ Language
-
getter/setter pair
- onAuthError ↔ void Function(BuildContext context)?
-
getter/setter pair
-
onEvent
→ Stream<
Event> -
no setter
- onTokenErrorWidget ↔ Widget?
-
getter/setter pair
- onWebViewLoadError ↔ void Function(BuildContext context, WebResourceError error)?
-
getter/setter pair
- reloadPageOnAppResume ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secret ↔ String
-
getter/setter pair
- service ↔ ApiService
-
getter/setter pair
- token ↔ String
-
getter/setter pair
- trackingId ↔ String?
-
getter/setter pair
- url ↔ String
-
getter/setter pair
- uuid ↔ String
-
getter/setter pair
- version ↔ String?
-
getter/setter pair
- webviewContainer ↔ WebviewContainer
-
getter/setter pair
- webViewController ↔ WebViewController?
-
getter/setter pair
Methods
-
authenticate(
{required String customerCode, String category = ""}) → Future< String> -
getWebViewContainer(
) → WebviewContainer -
home(
) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAllEvent(
Function callback) → StreamSubscription< Event> -
onAutoPaymentEvent(
Function callback) → StreamSubscription< Event> -
onBackButtonPressedEvent(
Function callback) → StreamSubscription< Event> -
onBackEvent(
Function callback) → StreamSubscription< Event> -
onErrorEvent(
Function callback) → StreamSubscription< Event> -
onGenericEvent(
Function callback) → StreamSubscription< Event> -
onGiftCardCopyEvent(
Function callback) → StreamSubscription< Event> -
onHomeBannerActionEvent(
Function callback) → StreamSubscription< Event> -
onMissionActionEvent(
Function callback) → StreamSubscription< Event> -
onPaymentEvent(
Function callback) → StreamSubscription< Event> -
onReferralCopyEvent(
Function callback) → StreamSubscription< Event> -
onTriviaCloseEvent(
Function callback) → StreamSubscription< Event> -
onTriviaFinishedEvent(
Function callback) → StreamSubscription< Event> -
onTriviaGameFinishedEvent(
Function callback) → StreamSubscription< Event> -
onWebViewLoadedEvent(
Function callback) → StreamSubscription< Event> -
refreshToken(
) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{required String uuid, required String secret, required Environment env, required Language language, required String customerCode, bool reloadPageOnAppResume = true, void onWebViewLoadError(BuildContext context, WebResourceError error)?, void onAuthError(BuildContext context)?, Widget? onTokenErrorWidget, String? version, String? trackingId}) → Future< Flourish>