WebviewContainer class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- WebviewContainer
Constructors
- WebviewContainer({Key? key, required Environment environment, required String apiToken, required String platformUrl, required Language language, required EventManager eventManager, required Endpoint endpoint, required Flourish flourish, String? version, String? trackingId, String? sdkVersion, String? redirectTo, String? resourceId, bool useHttp = false})
Properties
- apiToken → String
-
final
- endpoint → Endpoint
-
final
- environment → Environment
-
final
- eventManager → EventManager
-
final
- flourish → Flourish
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialLink → Uri
-
no setter
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- language → Language
-
final
- platformUrl → String
-
final
- redirectTo → String?
-
Optional deep-link target page (a web-app page key, e.g.
PARTNER_STORE_DETAIL). When null/empty the web app lands on its default entry point.final - resourceId → String?
-
Optional resource id for a dynamic redirectTo route (e.g. a store id).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkVersion → String?
-
final
- trackingId → String?
-
final
- useHttp → bool
-
Whether to load platformUrl over plain HTTP. Set only for local
development (see Flourish debug overrides); HTTPS otherwise.
final
- version → String?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → WebviewContainerState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited